property

package
v0.0.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithValue

func WithValue(name string, value interface{}) updater.Properties

WithValue sets a specific key-value pair within the properties map.

The name parameter specifies the key, and the value parameter specifies the value associated with that key.

Types

This section is empty.

Jump to