updater

package
v0.0.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2025 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Location

type Location interface {
	Apply(map[string]interface{})
}

Location is an interface that any location update configuration should implement.

type LocationFunc

type LocationFunc func(map[string]interface{})

LocationFunc is a function type that implements the Location interface.

func (LocationFunc) Apply

func (f LocationFunc) Apply(location map[string]interface{})

type Profile

type Profile interface {
	Apply(*ProfileData)
}

Profile is an interface that any profile update configuration should implement.

type ProfileData added in v0.0.4

type ProfileData struct {
	Attributes         map[string]interface{}
	PropertiesToRemove []string
}

ProfileData holds all the data needed to update the profile

func NewProfileData added in v0.0.4

func NewProfileData() *ProfileData

NewProfileData creates new instance of ProfileData

type ProfileFunc

type ProfileFunc func(*ProfileData)

ProfileFunc is a function type that implements the Profile interface.

func (ProfileFunc) Apply

func (f ProfileFunc) Apply(profile *ProfileData)

type Properties

type Properties interface {
	Apply(map[string]interface{})
}

Properties is an interface that any properties update configuration should implement.

type PropertiesFunc

type PropertiesFunc func(map[string]interface{})

PropertiesFunc is a function type that implements the Properties interface.

func (PropertiesFunc) Apply

func (f PropertiesFunc) Apply(properties map[string]interface{})

Jump to