getprofiles

package
v0.0.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FieldsUpdaterFunc

type FieldsUpdaterFunc func(url.Values)

FieldsUpdaterFunc is a type that wraps a function that updates URL query parameters.

func (FieldsUpdaterFunc) Apply

func (f FieldsUpdaterFunc) Apply(fields url.Values)

Apply calls the underlying function to update the URL query parameters.

type Param

type Param interface {
	Apply(fields url.Values)
}

Param is an interface that any parameter type should implement. It provides a method to apply the parameter as a query parameter.

func WithDefaultPageSize

func WithDefaultPageSize() Param

WithDefaultPageSize returns a parameter that sets the page size to its default value.

func WithFields

func WithFields(fieldName ...string) Param

WithFields returns a parameter that sets the specific fields to be retrieved for the profile. It accepts a variable number of field names and constructs the appropriate query parameter.

func WithPageSize

func WithPageSize(pageSize int) Param

WithPageSize returns a parameter that sets the page size for the request. It ensures that the page size is within the allowed range.

Jump to