Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithValue ¶
func WithValue(name string, value interface{}) updater.Properties
WithValue sets a specific key-value pair within the properties map.
The name parameter specifies the key, and the value parameter specifies the value associated with that key.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.